@@ -27,6 +27,7 @@ import socket
 import time
 from enum import IntEnum
 from typing import Tuple, TYPE_CHECKING
+import threading
 
 from PyQt5.QtCore import Qt, pyqtSignal, QThread
 from PyQt5.QtWidgets import (QTreeWidget, QTreeWidgetItem, QMenu, QGridLayout, QComboBox,
@@ -42,6 +43,7 @@ from electrum.logging import get_logger
 
 from .util import (Buttons, CloseButton, HelpButton, read_QIcon, char_width_in_lineedit,
                    PasswordLineEdit)
+from .util import QtEventListener, qt_event_listener
 
 if TYPE_CHECKING:
     from electrum.simple_config import SimpleConfig
@@ -52,26 +54,28 @@ _logger = get_logger(__name__)
 protocol_names = ['TCP', 'SSL']
 protocol_letters = 'ts'
 
-class NetworkDialog(QDialog):
-    def __init__(self, network, config, network_updated_signal_obj):
+class NetworkDialog(QDialog, QtEventListener):
+    def __init__(self, *, network: Network, config: 'SimpleConfig'):
         QDialog.__init__(self)
         self.setWindowTitle(_('Network'))
         self.setMinimumSize(500, 500)
         self.nlayout = NetworkChoiceLayout(network, config)
-        self.network_updated_signal_obj = network_updated_signal_obj
         vbox = QVBoxLayout(self)
         vbox.addLayout(self.nlayout.layout())
         vbox.addLayout(Buttons(CloseButton(self)))
-        self.network_updated_signal_obj.network_updated_signal.connect(
-            self.on_update)
-        util.register_callback(self.on_network, ['network_updated'])
+        self.register_callbacks()
+        self._cleaned_up = False
 
-    def on_network(self, event, *args):
-        self.network_updated_signal_obj.network_updated_signal.emit(event, args)
-
-    def on_update(self):
+    @qt_event_listener
+    def on_event_network_updated(self):
         self.nlayout.update()
 
+    def clean_up(self):
+        if self._cleaned_up:
+            return
+        self._cleaned_up = True
+        self.nlayout.clean_up()
+        self.unregister_callbacks()
 
 
 class NodesListWidget(QTreeWidget):
@@ -117,7 +121,7 @@ class NodesListWidget(QTreeWidget):
         menu.exec_(self.viewport().mapToGlobal(position))
 
     def keyPressEvent(self, event):
-        if event.key() in [ Qt.Key_F2, Qt.Key_Return, Qt.Key_Enter ]:
+        if event.key() in [Qt.Key_F2, Qt.Key_Return, Qt.Key_Enter]:
             self.on_activated(self.currentItem(), self.currentColumn())
         else:
             QTreeWidget.keyPressEvent(self, event)
@@ -148,7 +152,7 @@ class NodesListWidget(QTreeWidget):
                 x = connected_servers_item
             for i in interfaces:
                 star = ' *' if i == network.interface else ''
-                item = QTreeWidgetItem([f"{i.server.net_addr_str()}" + star, '%d'%i.tip])
+                item = QTreeWidgetItem([f"{i.server.to_friendly_name()}" + star, '%d'%i.tip])
                 item.setData(0, self.ITEMTYPE_ROLE, self.ItemType.CONNECTED_SERVER)
                 item.setData(0, self.SERVER_ADDR_ROLE, i.server)
                 item.setToolTip(0, str(i.server))
@@ -308,6 +312,12 @@ class NetworkChoiceLayout(object):
         self.fill_in_proxy_settings()
         self.update()
 
+    def clean_up(self):
+        if self.td:
+            self.td.found_proxy.disconnect()
+            self.td.stop()
+            self.td = None
+
     def check_disable_proxy(self, b):
         if not self.config.is_modifiable('proxy'):
             b = False
@@ -327,7 +337,7 @@ class NetworkChoiceLayout(object):
         server = net_params.server
         auto_connect = net_params.auto_connect
         if not self.server_e.hasFocus():
-            self.server_e.setText(server.net_addr_str())
+            self.server_e.setText(server.to_friendly_name())
         self.autoconnect_cb.setChecked(auto_connect)
 
         height_str = "%d "%(self.network.get_local_height()) + _('blocks')
@@ -396,11 +406,11 @@ class NetworkChoiceLayout(object):
     def set_proxy(self):
         net_params = self.network.get_parameters()
         if self.proxy_cb.isChecked():
-            proxy = { 'mode':str(self.proxy_mode.currentText()).lower(),
-                      'host':str(self.proxy_host.text()),
-                      'port':str(self.proxy_port.text()),
-                      'user':str(self.proxy_user.text()),
-                      'password':str(self.proxy_password.text())}
+            proxy = {'mode':str(self.proxy_mode.currentText()).lower(),
+                     'host':str(self.proxy_host.text()),
+                     'port':str(self.proxy_port.text()),
+                     'user':str(self.proxy_user.text()),
+                     'password':str(self.proxy_password.text())}
         else:
             proxy = None
             self.tor_cb.setChecked(False)
@@ -447,6 +457,7 @@ class TorDetector(QThread):
 
     def __init__(self):
         QThread.__init__(self)
+        self._stop_event = threading.Event()
 
     def run(self):
         # Probable ports for Tor to listen at
@@ -459,18 +470,25 @@ class TorDetector(QThread):
                     break
             else:
                 self.found_proxy.emit(None)
-            time.sleep(10)
+            stopping = self._stop_event.wait(10)
+            if stopping:
+                return
+
+    def stop(self):
+        self._stop_event.set()
+        self.exit()
+        self.wait()
 
     @staticmethod
     def is_tor_port(net_addr: Tuple[str, int]) -> bool:
         try:
-            s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-            s.settimeout(0.1)
-            s.connect(net_addr)
-            # Tor responds uniquely to HTTP-like requests
-            s.send(b"GET\n")
-            if b"Tor is not an HTTP Proxy" in s.recv(1024):
-                return True
+            with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
+                s.settimeout(0.1)
+                s.connect(net_addr)
+                # Tor responds uniquely to HTTP-like requests
+                s.send(b"GET\n")
+                if b"Tor is not an HTTP Proxy" in s.recv(1024):
+                    return True
         except socket.error:
             pass
         return False
