@@ -127,7 +127,8 @@ class Invoice(StoredObject):
     def get_outputs(self):
         if self.is_lightning():
             address = self.get_address()
-            outputs = [PartialTxOutput.from_address_and_value(address, int(self.get_amount_sat()))] if address else []
+            amount = self.get_amount_sat()
+            outputs = [PartialTxOutput.from_address_and_value(address, int(amount))] if address and amount else []
         else:
             outputs = self.outputs
         return outputs
@@ -155,7 +156,7 @@ class Invoice(StoredObject):
             return amount_msat
         return int(amount_msat // 1000)
 
-    def get_bip21_URI(self, lightning=None):
+    def get_bip21_URI(self, *, include_lightning: bool = False) -> Optional[str]:
         from electrum.util import create_bip21_uri
         addr = self.get_address()
         amount = self.get_amount_sat()
@@ -164,13 +165,15 @@ class Invoice(StoredObject):
         message = self.message
         extra = {}
         if self.time and self.exp:
-            extra['time'] = str(self.time)
-            extra['exp'] = str(self.exp)
-        # only if we can receive
+            extra['time'] = str(int(self.time))
+            extra['exp'] = str(int(self.exp))
+        lightning = self.lightning_invoice if include_lightning else None
         if lightning:
             extra['lightning'] = lightning
         if not addr and lightning:
             return "bitcoin:?lightning="+lightning
+        if not addr and not lightning:
+            return None
         uri = create_bip21_uri(addr, amount, message, extra_query_params=extra)
         return str(uri)
 
