@@ -37,8 +37,6 @@ import os
 import math
 import hashlib
 
-from .pem import *
-
 
 def SHA1(x):
     return hashlib.sha1(x).digest()
@@ -81,7 +79,7 @@ def numberToByteArray(n, howManyBytes=None):
     not be larger.  The returned bytearray will contain a big-endian
     encoding of the input integer (n).
     """
-    if howManyBytes == None:
+    if howManyBytes is None:
         howManyBytes = numBytes(n)
     b = bytearray(howManyBytes)
     for count in range(howManyBytes-1, -1, -1):
